<?php

declare(strict_types=1);

namespace Drupal\skribble;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the signing request entity type.
 *
 * phpcs:disable Drupal.Arrays.Array.LongLineDeclaration
 *
 * @see https://www.drupal.org/project/coder/issues/3185082
 */
final class SigningRequestAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account): AccessResult {
    return match($operation) {
      'view' => AccessResult::allowedIfHasPermissions($account, ['view skribble_signing_request', 'administer skribble_signing_request'], 'OR'),
      'update' => AccessResult::allowedIfHasPermissions($account, ['edit skribble_signing_request', 'administer skribble_signing_request'], 'OR'),
      'delete' => AccessResult::allowedIfHasPermissions($account, ['delete skribble_signing_request', 'administer skribble_signing_request'], 'OR'),
      default => AccessResult::neutral(),
    };
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL): AccessResult {
    return AccessResult::allowedIfHasPermissions($account, ['create skribble_signing_request', 'administer skribble_signing_request'], 'OR');
  }

}
